@@ -2,18 +2,18 @@
 
 #pragma once
 
-#include "Tag.h"
-#include "plugin/Component.h"
-#include "plugin/TaggedComponent.h"
+#include "zeek-config.h"
 
-#include "../zeek-config.h"
-#include "../util.h"
+#include "zeek/analyzer/Tag.h"
+#include "zeek/plugin/Component.h"
+#include "zeek/plugin/TaggedComponent.h"
 
-class Connection;
+#include "zeek/util.h"
 
-namespace analyzer {
+ZEEK_FORWARD_DECLARE_NAMESPACED(Connection, zeek);
+ZEEK_FORWARD_DECLARE_NAMESPACED(Analyzer, zeek, analyzer);
 
-class Analyzer;
+namespace zeek::analyzer {
 
 /**
  * Component description for plugins providing analyzers.
@@ -35,7 +35,7 @@ public:
 	 *
 	 * @param factory A factory function to instantiate instances of the
 	 * analyzer's class, which must be derived directly or indirectly
-	 * from analyzer::Analyzer. This is typically a static \c
+	 * from zeek::analyzer::Analyzer. This is typically a static \c
 	 * Instatiate() method inside the class that just allocates and
 	 * returns a new instance.
 	 *
@@ -107,4 +107,8 @@ private:
 	bool enabled;	// True if the analyzer is enabled.
 };
 
-}
+} // namespace zeek::analyzer
+
+namespace analyzer {
+	using Component [[deprecated("Remove in v4.1. Use zeek::analyzer::Component.")]] = zeek::analyzer::Component;
+} // namespace analyzer
