@@ -2,26 +2,26 @@
 
 #pragma once
 
-#include "analyzer/Analyzer.h"
-#include "IPAddr.h"
-#include "TCP_Endpoint.h"
-#include "TCP_Flags.h"
-#include "Conn.h"
+#include "zeek/analyzer/Analyzer.h"
+#include "zeek/IPAddr.h"
+#include "zeek/analyzer/protocol/tcp/TCP_Endpoint.h"
+#include "zeek/analyzer/protocol/tcp/TCP_Flags.h"
+#include "zeek/Conn.h"
 
 // We define two classes here:
 // - TCP_Analyzer is the analyzer for the TCP protocol itself.
 // - TCP_ApplicationAnalyzer is an abstract base class for analyzers for a
 //   protocol running on top of TCP.
-// 
-namespace analyzer { namespace pia { class PIA_TCP; } };
+//
 
-namespace analyzer { namespace tcp {
+ZEEK_FORWARD_DECLARE_NAMESPACED(PIA_TCP, zeek, analyzer::pia);
+ZEEK_FORWARD_DECLARE_NAMESPACED(TCP_Endpoint, zeek, analyzer::tcp);
+ZEEK_FORWARD_DECLARE_NAMESPACED(TCP_Reassembler, zeek, analyzer::tcp);
+ZEEK_FORWARD_DECLARE_NAMESPACED(TCP_ApplicationAnalyzer, zeek, analyzer::tcp);
 
-class TCP_Endpoint;
-class TCP_ApplicationAnalyzer;
-class TCP_Reassembler;
+namespace zeek::analyzer::tcp {
 
-class TCP_Analyzer : public analyzer::TransportLayerAnalyzer {
+class TCP_Analyzer final : public analyzer::TransportLayerAnalyzer {
 public:
 	explicit TCP_Analyzer(Connection* conn);
 	~TCP_Analyzer() override;
@@ -32,15 +32,15 @@ public:
 	// independently of whether we do any reassembly.
 	void AddChildPacketAnalyzer(analyzer::Analyzer* a);
 
-	Analyzer* FindChild(ID id) override;
-	Analyzer* FindChild(Tag tag) override;
-	bool RemoveChildAnalyzer(ID id) override;
+	Analyzer* FindChild(analyzer::ID id) override;
+	Analyzer* FindChild(analyzer::Tag tag) override;
+	bool RemoveChildAnalyzer(analyzer::ID id) override;
 
 	// True if the connection has closed in some sense, false otherwise.
-	int IsClosed() const	{ return orig->did_close || resp->did_close; }
-	int BothClosed() const	{ return orig->did_close && resp->did_close; }
+	bool IsClosed() const	{ return orig->did_close || resp->did_close; }
+	bool BothClosed() const	{ return orig->did_close && resp->did_close; }
 
-	int IsPartial() const	{ return is_partial; }
+	bool IsPartial() const	{ return is_partial; }
 
 	bool HadGap(bool orig) const;
 
@@ -58,10 +58,10 @@ public:
 	// which we have seen a FIN) - for it, data is pending unless
 	// everything's been delivered up to the FIN.  For its peer,
 	// the test is whether it has any outstanding, un-acked data.
-	int DataPending(TCP_Endpoint* closing_endp);
+	bool DataPending(TCP_Endpoint* closing_endp);
 
-	void SetContentsFile(unsigned int direction, BroFile* f) override;
-	BroFile* GetContentsFile(unsigned int direction) const override;
+	void SetContentsFile(unsigned int direction, FilePtr f) override;
+	FilePtr GetContentsFile(unsigned int direction) const override;
 
 	// From Analyzer.h
 	void UpdateConnVal(RecordVal *conn_val) override;
@@ -79,7 +79,8 @@ protected:
 	// Analyzer interface.
 	void Init() override;
 	void Done() override;
-	void DeliverPacket(int len, const u_char* data, bool orig, uint64_t seq, const IP_Hdr* ip, int caplen) override;
+	void DeliverPacket(int len, const u_char* data, bool orig, uint64_t seq,
+	                   const IP_Hdr* ip, int caplen) override;
 	void DeliverStream(int len, const u_char* data, bool orig) override;
 	void Undelivered(uint64_t seq, int len, bool orig) override;
 	void FlipRoles() override;
@@ -93,7 +94,7 @@ protected:
 
 	// Returns true if the checksum is valid, false if not (and in which
 	// case also updates the status history of the endpoint).
-	bool ValidateChecksum(const struct tcphdr* tp, TCP_Endpoint* endpoint,
+	bool ValidateChecksum(const IP_Hdr* ip, const struct tcphdr* tp, TCP_Endpoint* endpoint,
 				int len, int caplen);
 
 	void SetPartialStatus(TCP_Flags flags, bool is_orig);
@@ -107,41 +108,41 @@ protected:
 	void UpdateStateMachine(double t,
 			TCP_Endpoint* endpoint, TCP_Endpoint* peer,
 			uint32_t base_seq, uint32_t ack_seq,
-			int len, int32_t delta_last, int is_orig, TCP_Flags flags,
-			int& do_close, int& gen_event);
+			int len, int32_t delta_last, bool is_orig, TCP_Flags flags,
+			bool& do_close, bool& gen_event);
 
 	void UpdateInactiveState(double t,
 				TCP_Endpoint* endpoint, TCP_Endpoint* peer,
 				uint32_t base_seq, uint32_t ack_seq,
-				int len, int is_orig, TCP_Flags flags,
-				int& do_close, int& gen_event);
+				int len, bool is_orig, TCP_Flags flags,
+				bool& do_close, bool& gen_event);
 
 	void UpdateSYN_SentState(TCP_Endpoint* endpoint, TCP_Endpoint* peer,
-				 int len, int is_orig, TCP_Flags flags,
-				 int& do_close, int& gen_event);
+				 int len, bool is_orig, TCP_Flags flags,
+				 bool& do_close, bool& gen_event);
 
 	void UpdateEstablishedState(TCP_Endpoint* endpoint, TCP_Endpoint* peer,
-				    TCP_Flags flags, int& do_close, int& gen_event);
+				    TCP_Flags flags, bool& do_close, bool& gen_event);
 
 	void UpdateClosedState(double t, TCP_Endpoint* endpoint,
 				int32_t delta_last, TCP_Flags flags,
-				int& do_close);
+				bool& do_close);
 
 	void UpdateResetState(int len, TCP_Flags flags);
 
 	void GeneratePacketEvent(uint64_t rel_seq, uint64_t rel_ack,
 				 const u_char* data, int len, int caplen,
-				 int is_orig, TCP_Flags flags);
+				 bool is_orig, TCP_Flags flags);
 
-	int DeliverData(double t, const u_char* data, int len, int caplen,
-			const IP_Hdr* ip, const struct tcphdr* tp,
-			TCP_Endpoint* endpoint, uint64_t rel_data_seq,
-			int is_orig, TCP_Flags flags);
+	bool DeliverData(double t, const u_char* data, int len, int caplen,
+	                 const IP_Hdr* ip, const struct tcphdr* tp,
+	                 TCP_Endpoint* endpoint, uint64_t rel_data_seq,
+	                 bool is_orig, TCP_Flags flags);
 
-	void CheckRecording(int need_contents, TCP_Flags flags);
-	void CheckPIA_FirstPacket(int is_orig, const IP_Hdr* ip);
+	void CheckRecording(bool need_contents, TCP_Flags flags);
+	void CheckPIA_FirstPacket(bool is_orig, const IP_Hdr* ip);
 
-	friend class ConnectionTimer;
+	friend class detail::ConnectionTimer;
 	void AttemptTimer(double t);
 	void PartialCloseTimer(double t);
 	void ExpireTimer(double t);
@@ -151,8 +152,8 @@ protected:
 
 	void EndpointEOF(TCP_Reassembler* endp);
 	void ConnectionClosed(TCP_Endpoint* endpoint,
-					TCP_Endpoint* peer, int gen_event);
-	void ConnectionFinished(int half_finished);
+					TCP_Endpoint* peer, bool gen_event);
+	void ConnectionFinished(bool half_finished);
 	void ConnectionReset();
 	void PacketWithRST();
 
@@ -161,15 +162,18 @@ protected:
 	// A couple utility functions that may also be useful to derived analyzers.
 	static uint64_t get_relative_seq(const TCP_Endpoint* endpoint,
 	                               uint32_t cur_base, uint32_t last,
-	                               uint32_t wraps, bool* underflow = 0);
+	                               uint32_t wraps, bool* underflow = nullptr);
 
 	static int get_segment_len(int payload_len, TCP_Flags flags);
 
 private:
+
+	void SynWeirds(TCP_Flags flags, TCP_Endpoint* endpoint, int data_len) const;
+
 	TCP_Endpoint* orig;
 	TCP_Endpoint* resp;
 
-	typedef list<analyzer::Analyzer*> analyzer_list;
+	using analyzer_list = std::list<analyzer::Analyzer*>;
 	analyzer_list packet_children;
 
 	unsigned int first_packet_seen: 2;
@@ -192,12 +196,10 @@ private:
 class TCP_ApplicationAnalyzer : public analyzer::Analyzer {
 public:
 	TCP_ApplicationAnalyzer(const char* name, Connection* conn)
-	: Analyzer(name, conn)
-		{ tcp = 0; }
+		: Analyzer(name, conn), tcp(nullptr) { }
 
 	explicit TCP_ApplicationAnalyzer(Connection* conn)
-	: Analyzer(conn)
-		{ tcp = 0; }
+		: Analyzer(conn), tcp(nullptr) { }
 
 	~TCP_ApplicationAnalyzer() override { }
 
@@ -220,8 +222,8 @@ public:
 	// is now fully closed, a connection_finished event will be
 	// generated; otherwise not.
 	virtual void ConnectionClosed(analyzer::tcp::TCP_Endpoint* endpoint,
-				      analyzer::tcp::TCP_Endpoint* peer, int gen_event);
-	virtual void ConnectionFinished(int half_finished);
+				      analyzer::tcp::TCP_Endpoint* peer, bool gen_event);
+	virtual void ConnectionFinished(bool half_finished);
 	virtual void ConnectionReset();
 
 	// Called whenever a RST packet is seen - sometimes the invocation
@@ -229,13 +231,13 @@ public:
 	virtual void PacketWithRST();
 
 	void DeliverPacket(int len, const u_char* data, bool orig,
-					uint64_t seq, const IP_Hdr* ip, int caplen) override;
+	                   uint64_t seq, const IP_Hdr* ip, int caplen) override;
 	void Init() override;
 
 	// This suppresses violations if the TCP connection wasn't
 	// fully established.
 	void ProtocolViolation(const char* reason,
-					const char* data = 0, int len = 0) override;
+					const char* data = nullptr, int len = 0) override;
 
 	// "name" and "val" both now belong to this object, which needs to
 	//  delete them when done with them.
@@ -255,8 +257,8 @@ public:
 	// These are passed on from TCP_Analyzer.
 	virtual void EndpointEOF(bool is_orig)	{ }
 	virtual void ConnectionClosed(TCP_Endpoint* endpoint,
-					TCP_Endpoint* peer, int gen_event) 	{ }
-	virtual void ConnectionFinished(int half_finished)	{ }
+					TCP_Endpoint* peer, bool gen_event) 	{ }
+	virtual void ConnectionFinished(bool half_finished)	{ }
 	virtual void ConnectionReset()	{ }
 	virtual void PacketWithRST()	{ }
 };
@@ -266,8 +268,8 @@ class TCPStats_Endpoint {
 public:
 	explicit TCPStats_Endpoint(TCP_Endpoint* endp);
 
-	int DataSent(double t, uint64_t seq, int len, int caplen, const u_char* data,
-			const IP_Hdr* ip, const struct tcphdr* tp);
+	bool DataSent(double t, uint64_t seq, int len, int caplen, const u_char* data,
+	              const IP_Hdr* ip, const struct tcphdr* tp);
 
 	RecordVal* BuildStats();
 
@@ -297,10 +299,20 @@ public:
 
 protected:
 	void DeliverPacket(int len, const u_char* data, bool is_orig,
-					uint64_t seq, const IP_Hdr* ip, int caplen) override;
+	                   uint64_t seq, const IP_Hdr* ip, int caplen) override;
 
 	TCPStats_Endpoint* orig_stats;
 	TCPStats_Endpoint* resp_stats;
 };
 
-} } // namespace analyzer::* 
+} // namespace zeek::analyzer::tcp
+
+namespace analyzer::tcp {
+
+using TCP_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::tcp::TCP_Analyzer.")]] = zeek::analyzer::tcp::TCP_Analyzer;
+using TCP_ApplicationAnalyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::tcp::TCP_ApplicationAnalyzer.")]] = zeek::analyzer::tcp::TCP_ApplicationAnalyzer;
+using TCP_SupportAnalyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::tcp::TCP_SupportAnalyzer.")]] = zeek::analyzer::tcp::TCP_SupportAnalyzer;
+using TCPStats_Endpoint [[deprecated("Remove in v4.1. Use zeek::analyzer::tcp::TCPStats_Endpoint.")]] = zeek::analyzer::tcp::TCPStats_Endpoint;
+using TCPStats_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::tcp::TCPStats_Analyzer.")]] = zeek::analyzer::tcp::TCPStats_Analyzer;
+
+} // namespace analyzer::tcp
