@@ -4,12 +4,13 @@
 
 #include "zeek-config.h"
 
-#include "zlib.h"
-#include "analyzer/protocol/tcp/TCP.h"
+#include <zlib.h>
 
-namespace analyzer { namespace zip {
+#include "zeek/analyzer/protocol/tcp/TCP.h"
 
-class ZIP_Analyzer : public tcp::TCP_SupportAnalyzer {
+namespace zeek::analyzer::zip {
+
+class ZIP_Analyzer final : public analyzer::tcp::TCP_SupportAnalyzer {
 public:
 	enum Method { GZIP, DEFLATE };
 
@@ -27,4 +28,10 @@ protected:
 	Method method;
 };
 
-} } // namespace analyzer::* 
+} // namespace zeek::analyzer::zip
+
+namespace analyzer::zip {
+
+using ZIP_Analyzer [[deprecated("Remove in v4.1. Use zeek::analyzer::zip::ZIP_Analyzer.")]] = zeek::analyzer::zip::ZIP_Analyzer;
+
+} // namespace analyzer::zip
