@@ -2,18 +2,15 @@
 
 #pragma once
 
-#include "Timer.h"
-
 #include <string>
+#include "zeek/Timer.h"
 
-using std::string;
-
-namespace file_analysis {
+namespace zeek::file_analysis::detail {
 
 /**
  * Timer to periodically check if file analysis for a given file is inactive.
  */
-class FileTimer : public Timer {
+class FileTimer final : public zeek::detail::Timer {
 public:
 
 	/**
@@ -22,7 +19,7 @@ public:
 	 * @param id the file identifier which will be checked for inactivity.
 	 * @param interval amount of time after \a t to check for inactivity.
 	 */
-	FileTimer(double t, const string& id, double interval);
+	FileTimer(double t, const std::string& id, double interval);
 
 	/**
 	 * Check inactivity of file_analysis::File corresponding to #file_id,
@@ -30,10 +27,16 @@ public:
 	 * @param t current unix time
 	 * @param is_expire true if all pending timers are being expired.
 	 */
-	void Dispatch(double t, int is_expire) override;
+	void Dispatch(double t, bool is_expire) override;
 
 private:
-	string file_id;
+	std::string file_id;
 };
 
+} // namespace zeek::file_analysis::detail
+
+namespace file_analysis {
+
+using FileTimer [[deprecated("Remove in v4.1. Use zeek::file_analysis::detail::FileTimer.")]] = zeek::file_analysis::detail::FileTimer;
+
 } // namespace file_analysis
