@@ -2,17 +2,17 @@
 
 #pragma once
 
+#include <sys/types.h>
 #include <iostream>
 #include <vector>
 #include <fstream>
 #include <memory>
 #include <unordered_map>
-#include <sys/types.h>
 
-#include "input/ReaderBackend.h"
-#include "threading/formatters/Ascii.h"
+#include "zeek/input/ReaderBackend.h"
+#include "zeek/threading/formatters/Ascii.h"
 
-namespace input { namespace reader {
+namespace zeek::input::reader::detail {
 
 /**
  * Reader for Configuration files.
@@ -37,23 +37,27 @@ protected:
 	bool DoHeartbeat(double network_time, double current_time) override;
 
 private:
-	bool GetLine(string& str);
+	bool GetLine(std::string& str);
 	bool OpenFile();
 
-	ifstream file;
+	std::ifstream file;
 	time_t mtime;
 	ino_t ino;
 
 	bool fail_on_file_problem;
 
-	string set_separator;
-	string empty_field;
+	std::string set_separator;
+	std::string empty_field;
 
-	std::unique_ptr<threading::formatter::Formatter> formatter;
+	std::unique_ptr<threading::Formatter> formatter;
 	std::unordered_map<std::string, std::tuple<TypeTag, TypeTag>> option_types;
 	std::unordered_map<std::string, std::string> option_values;
 };
 
+} // namespace zeek::input::reader::detail
 
-}
-}
+namespace input::reader {
+
+using Config [[deprecated("Remove in v4.1. Use zeek::input::reader::detail::Config.")]] = zeek::input::reader::detail::Config;
+
+} // namespace input::reader
