@@ -6,10 +6,9 @@ extern "C" {
 #include <pcap.h>
 }
 
-#include "../PktDumper.h"
+#include "zeek/iosource/PktDumper.h"
 
-namespace iosource {
-namespace pcap {
+namespace zeek::iosource::pcap {
 
 class PcapDumper : public PktDumper {
 public:
@@ -32,5 +31,10 @@ private:
 	pcap_t* pd;
 };
 
-}
-}
+} // namespace zeek::iosource::pcap
+
+namespace iosource::pcap {
+
+using PcapDumper [[deprecated("Remove in v4.1. Use zeek::iosource::pcap::PcapDumper.")]] = zeek::iosource::pcap::PcapDumper;
+
+} // namespace iosource::pcap
