@@ -2,11 +2,11 @@
 
 #pragma once
 
-#include "WriterBackend.h"
+#include "zeek/logging/WriterBackend.h"
 
-namespace logging  {
+ZEEK_FORWARD_DECLARE_NAMESPACED(Manager, zeek, logging);
 
-class Manager;
+namespace zeek::logging  {
 
 /**
  * Bridge class between the logging::Manager and backend writer threads. The
@@ -38,7 +38,8 @@ public:
 	 *
 	 * Frontends must only be instantiated by the main thread.
 	 */
-	WriterFrontend(const WriterBackend::WriterInfo& info, EnumVal* stream, EnumVal* writer, bool local, bool remote);
+	WriterFrontend(const WriterBackend::WriterInfo& info, EnumVal* stream,
+	               EnumVal* writer, bool local, bool remote);
 
 	/**
 	 * Destructor.
@@ -208,4 +209,10 @@ protected:
 	threading::Value*** write_buffer;	// Buffer of size WRITER_BUFFER_SIZE.
 };
 
-}
+} // namespace zeek::logging
+
+namespace logging {
+
+using WriterFrontend [[deprecated("Remove in v4.1. Use zeek::logging::WriterFrontend.")]] = zeek::logging::WriterFrontend;
+
+} // namespace logging
