@@ -29,6 +29,17 @@
 #include <vector>
 #include <memory> // std::unique_ptr
 
+#ifdef TIME_WITH_SYS_TIME
+# include <sys/time.h>
+# include <time.h>
+#else
+# ifdef HAVE_SYS_TIME_H
+#  include <sys/time.h>
+# else
+#  include <time.h>
+# endif
+#endif
+
 #ifdef DEBUG
 
 #include <assert.h>
